@@ -12,9 +12,6 @@ from time import sleep
 from setuptools import setup, Extension
 
 
-#TO DO LIST:@
-#MAKE AN ADVANDED PRINT
-#
 
 RETURN = []
 Black= "\u001b[30m"
@@ -32,7 +29,6 @@ COLORLIST = ["\u001b[30m","\u001b[31m","\u001b[32m","\u001b[33m","\u001b[34m","\
 def INPUT(text,x,y,NOENTER=False, NPRINT=False):
     OS = os.name
     if OS == "nt":
-
         #posix
         #nt
         print(text, end='')
@@ -86,7 +82,6 @@ def INPUT(text,x,y,NOENTER=False, NPRINT=False):
                     print("                             \033[A")
                     f.close()
                     break
-                    #STORE IT IN A VARIABLE
                 else:
                     if NPRINT == True:
                         sys.stdout.write(F"{text}")
@@ -108,20 +103,16 @@ def INPUT(text,x,y,NOENTER=False, NPRINT=False):
             f = open("keys.txt", "a")
             PRINT = False
             key = getch.getch()
-            ESCCODES = ord(key)
+            try:
+                ESCCODES = ord(key)
+            except:
+                pass
             if ESCCODES == 10:
                 break
             elif ESCCODES == 127:
-                sys.stdout.write('\r' + (' ' * shutil.get_terminal_size()[0]))
-                print ("\033[A")
-            else:
-                pass
-            if key == Fr'\x9c':
-                f.write(u"\xa3")
-            elif key == 'Â':
                 pass
             else:
-                f.write(F"{key}")
+                pass
             if PRINT == True:
                 print(key)
                 break
@@ -154,7 +145,6 @@ def INPUT(text,x,y,NOENTER=False, NPRINT=False):
                 print("                             \033[A")
                 f.close()
                 break
-                #STORE IT IN A VARIABLE
             else:
                 if NPRINT == True:
                     sys.stdout.write(F"{text}")
